# -*- coding: utf-8 -*-

from tests.wotb import WoTBTestCase


class WOTBAccountsTestCase(WoTBTestCase):

    def setUp(self):
        super(WOTBAccountsTestCase, self).setUp()

        self.ids = [1000000001, 1000000002]

    def test_list(self):
        response = self.api.accounts.list(search='demo', limit=5)
        self.assertEqual(5, len(response))

    def test_info(self):
        response = self.api.accounts.info(account_id=self.ids)

        self.assertEqual(len(self.ids), len(response))

        for id_ in self.ids:
            self.assertIn(str(id_), response)

    def test_achievements(self):
        response = self.api.accounts.achievements(account_id=self.ids)

        self.assertEqual(len(self.ids), len(response))

        for id_ in self.ids:
            self.assertIn(str(id_), response)



# -*- coding: utf-8 -*-

from tests.wot import WotTestCase


class WOTRatingsTestCase(WotTestCase):

    def setUp(self):
        super(WOTRatingsTestCase, self).setUp()
        self.account_id = 1000000001
        self.rank_field = 'frags_count'

    def test_types(self):
        self.assertValidResponse(self.api.ratings.types)

    def test_dates(self):
        self.assertValidResponse(self.api.ratings.dates, type='all')

    def test_accounts(self):
        self.assertValidResponse(self.api.ratings.accounts, type='all',
                                 account_id=self.account_id)

    def test_neighbors(self):
        self.assertValidResponse(self.api.ratings.neighbors, type='all',
                                 account_id=self.account_id, rank_field=self.rank_field)

    def test_top(self):
        self.assertValidResponse(self.api.ratings.top, type='all',
                                 rank_field=self.rank_field)



# -*- coding: utf-8 -*-

from tests.wotb import WoTBTestCase


class WOTBEncyclopediaTestCase(WoTBTestCase):

    def setUp(self):
        super(WOTBEncyclopediaTestCase, self).setUp()
        self.tank_id = 1
        self.nation = 'ussr'

    def test_vehicles(self):
        self.assertValidResponse(self.api.encyclopedia.vehicles)

    def test_vehicle_profiles(self):
        self.assertValidResponse(self.api.encyclopedia.vehicle_profiles,
                                 tank_id=self.tank_id)

    def test_modules(self):
        self.assertValidResponse(self.api.encyclopedia.modules)

    def test_provisions(self):
        self.assertValidResponse(self.api.encyclopedia.provisions)

    def test_info(self):
        self.assertValidResponse(self.api.encyclopedia.info)



# -*- coding: utf-8 -*-

from tests.wot import WotTestCase


class WOTGlobalWarTestCase(WotTestCase):

    def setUp(self):
        super(WOTGlobalWarTestCase, self).setUp()
        self.map_id = 'globalmap'
        self.clan_id = 1000000001
        self.account_id = 1000000000
        self.province_id = 'US_01'

    def test_clans(self):
        response = self.api.globalwar.clans(map_id=self.map_id)
        self.assertGreater(len(response), 0)

    def test_fame_points(self):
        response = self.api.globalwar.fame_points(map_id=self.map_id,
                                                  account_id=self.account_id)
        self.assertIn(str(self.account_id), response)

    def test_maps(self):
        response = self.api.globalwar.maps()
        self.assertGreater(len(response), 0)

    def test_provinces(self):
        response = self.api.globalwar.provinces(map_id=self.map_id)
        self.assertGreater(len(response), 0)

    def test_tournaments(self):
        self.assertValidResponse(self.api.globalwar.tournaments,
                                 map_id=self.map_id, province_id=self.province_id)

    def test_fame_points_history(self):
        # Just skipping since we need a valid access token,
        #   which is unavailable this time
        pass

    def test_alley_of_fame(self):
        self.api.globalwar.alley_of_fame(map_id=self.map_id)

    def test_battles(self):
        self.api.globalwar.battles(map_id=self.map_id, clan_id=self.clan_id)



# -*- coding: utf-8 -*-

from tests.wot import WotTestCase


class WOTClanRatingsTestCase(WotTestCase):

    def setUp(self):
        super(WOTClanRatingsTestCase, self).setUp()
        self.clan_id = 1000000001
        self.rating_period = 'all'
        self.rank_field = 'efficiency'

    def test_types(self):
        self.assertValidResponse(self.api.clan_ratings.types)

    def test_dates(self):
        self.assertValidResponse(self.api.clan_ratings.dates, type=self.rating_period, clan_id=self.clan_id)

    def test_clans(self):
        self.assertValidResponse(self.api.clan_ratings.clans, type=self.rating_period, clan_id=self.clan_id)

    def test_neighbors(self):
        self.assertValidResponse(self.api.clan_ratings.neighbors, type=self.rating_period, clan_id=self.clan_id,
                                 rank_field=self.rank_field)

    def test_top(self):
        self.assertValidResponse(self.api.clan_ratings.top, type=self.rating_period, rank_field=self.rank_field)



# -*- coding: utf-8 -*-

from tests.wot import WotTestCase


class WOTStrongholdsTestCase(WotTestCase):

    def setUp(self):
        super(WOTStrongholdsTestCase, self).setUp()
        self.clan_id = 1000000001
        self.account_id = 1000000000
        self.province_id = 'US_01'

    def test_info(self):
        self.assertValidResponse(self.api.strongholds.info, clan_id=self.clan_id)

    def test_structures(self):
        self.assertValidResponse(self.api.strongholds.structures)

    def test_account_stats(self):
        self.assertValidResponse(self.api.strongholds.account_stats, account_id=self.account_id)



# -*- coding: utf-8 -*-

from tests.wotb import WoTBTestCase


class WOTBTanksTestCase(WoTBTestCase):

    def setUp(self):
        super(WOTBTanksTestCase, self).setUp()
        self.account_id = 1000000000

    def test_stats(self):
        self.assertValidResponse(self.api.tanks.stats, account_id=self.account_id)

    def test_achievements(self):
        self.assertValidResponse(self.api.tanks.achievements, account_id=self.account_id)



# -*- coding: utf-8 -*-

from tests.wgn import WGNTestCase

from wargaming.exceptions import APIError


class WGNClansTestCase(WGNTestCase):

    def setUp(self):
        super(WGNClansTestCase, self).setUp()
        self.clan_id = 1000000000

    def test_list(self):
        response = self.api.clans.list(limit=3)
        self.assertEqual(3, len(response))

    def test_info(self):
        # Empty `clan_id` parameter
        self.assertRaises(APIError, self.api.clans.info)


        response = self.api.clans.info(clan_id=self.clan_id)
        self.assertIn(str(self.clan_id), response)
        self.assertEqual(1, len(response))

    def test_membersinfo(self):
        account_id = 1000000000
        response = self.api.clans.membersinfo(account_id=account_id)

        self.assertIn(str(account_id), response)



# -*- coding: utf-8 -*-

from tests.wot import WotTestCase


class WOTEncyclopediaTestCase(WotTestCase):

    def setUp(self):
        super(WOTEncyclopediaTestCase, self).setUp()
        self.tank_id = 1
        self.nation = 'ussr'

    def test_tanks(self):
        self.assertValidResponse(self.api.encyclopedia.tanks)

    def test_tank_info(self):
        self.assertValidResponse(self.api.encyclopedia.tank_info,
                                 tank_id=self.tank_id)

    def test_tank_engines(self):
        self.assertValidResponse(self.api.encyclopedia.tank_engines,
                                 nation=self.nation)

    def test_tank_turrets(self):
        self.assertValidResponse(self.api.encyclopedia.tank_turrets,
                                 nation=self.nation)

    def test_tank_radios(self):
        self.assertValidResponse(self.api.encyclopedia.tank_radios,
                                 nation=self.nation)

    def test_tank_suspensions(self):
        self.assertValidResponse(self.api.encyclopedia.tank_suspensions,
                                 nation=self.nation)

    def test_tank_guns(self):
        self.assertValidResponse(self.api.encyclopedia.tank_guns,
                                 tank_id=self.tank_id)

    def test_achievements(self):
        self.assertValidResponse(self.api.encyclopedia.achievements)

    def test_info(self):
        self.assertValidResponse(self.api.encyclopedia.info)

    def test_arenas(self):
        self.assertValidResponse(self.api.encyclopedia.arenas)

    def test_vehicles(self):
        self.assertValidResponse(self.api.encyclopedia.vehicles)

    def test_vehicle_profile(self):
        self.assertValidResponse(self.api.encyclopedia.vehicle_profile,
                                 tank_id=1)



# -*- coding: utf-8 -*-

from tests.wot import WotTestCase


class WOTClansTestCase(WotTestCase):

    def setUp(self):
        super(WOTClansTestCase, self).setUp()
        self.clan_id = 1000000000

    def test_provinces(self):
        # Have no ideas what that method should returns, so just verifying
        #   that request was made
        # TODO: check for proper response
        self.api.clans.provinces(clan_id=self.clan_id)



# -*- coding: utf-8 -*-

from tests.wot import WotTestCase


class WOTAuthTestCase(WotTestCase):

    def setUp(self):
        super(WOTAuthTestCase, self).setUp()

    def test_login(self):
        response = self.api.auth.login(redirect_uri='https://na.wargaming.net/developers/api_explorer/wot/auth/login/complete/',
                                       nofollow=True)
        self.assertIn('location', response)
